summaryrefslogtreecommitdiff
path: root/libraries/base/GHC/Stack
diff options
context:
space:
mode:
Diffstat (limited to 'libraries/base/GHC/Stack')
-rw-r--r--libraries/base/GHC/Stack/Types.hs5
1 files changed, 2 insertions, 3 deletions
diff --git a/libraries/base/GHC/Stack/Types.hs b/libraries/base/GHC/Stack/Types.hs
index 1eee18b8f3..265b3c75b8 100644
--- a/libraries/base/GHC/Stack/Types.hs
+++ b/libraries/base/GHC/Stack/Types.hs
@@ -51,9 +51,8 @@ import GHC.Classes (Eq)
import GHC.Types (Char, Int)
-- Make implicit dependency known to build system
-import GHC.Tuple () -- See Note [Depend on GHC.Tuple] in GHC.Base
-import GHC.Integer () -- See Note [Depend on GHC.Integer] in GHC.Base
-import GHC.Natural () -- See Note [Depend on GHC.Natural] in GHC.Base
+import GHC.Tuple () -- See Note [Depend on GHC.Tuple] in GHC.Base
+import GHC.Num.Integer () -- See Note [Depend on GHC.Num.Integer] in GHC.Base
----------------------------------------------------------------------
-- Explicit call-stacks built via ImplicitParams